# Generated by roxygen2: do not edit by hand

S3method(arid_plot,default)
S3method(print,aridagri_path)
S3method(print,aridagri_pca)
S3method(print,aridagri_stability)
export(anova_alpha_lattice)
export(anova_augmented)
export(anova_crd)
export(anova_factorial)
export(anova_factorial_3way)
export(anova_latin)
export(anova_rbd)
export(anova_rbd_pooled)
export(anova_spd)
export(anova_spd_ab_cd)
export(anova_spd_ab_main)
export(anova_spd_c_main_ab_sub)
export(anova_spd_pooled)
export(anova_sspd)
export(anova_sspd_pooled)
export(anova_strip)
export(arid_plot)
export(check_assumptions)
export(correlation_analysis)
export(crop_growth_analysis)
export(economic_analysis)
export(economic_indices)
export(export_results)
export(harvest_index)
export(nue_calculate)
export(nutrient_response)
export(path_analysis)
export(pca_analysis)
export(perform_posthoc)
export(sem_analysis)
export(stability_analysis)
export(thermal_indices)
export(yield_gap_analysis)
importFrom(stats,aggregate)
importFrom(stats,anova)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,bartlett.test)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,df.residual)
importFrom(stats,fitted)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,prcomp)
importFrom(stats,predict)
importFrom(stats,qt)
importFrom(stats,qtukey)
importFrom(stats,reshape)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(utils,head)
