#' Package imports
#'
#' @importFrom stats aggregate anova aov as.formula bartlett.test coef cor cor.test df.residual fitted lm na.omit pchisq pf prcomp predict qt qtukey reshape residuals sd shapiro.test
#' @importFrom utils head
#' @name imports
NULL
