% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/agronomic_analysis.R
\name{economic_indices}
\alias{economic_indices}
\title{Economic Efficiency Indices (B:C Ratio)}
\usage{
economic_indices(gross_return, total_cost, verbose = TRUE)
}
\arguments{
\item{gross_return}{Gross returns (Rs/ha)}

\item{total_cost}{Total cost (Rs/ha)}

\item{verbose}{Logical. If TRUE (default), prints formatted output to console.}
}
\value{
Data frame with economic indices
}
\description{
Calculates B:C ratio and economic efficiency metrics.
}
\examples{
economic_indices(gross_return = c(75000, 82000), total_cost = c(35000, 38000))

}
\author{
Lalit Kumar Rolaniya, Ram Lal Jat, Monika Punia, Raja Ram Choudhary
}
